@@ -88,13 +88,13 @@ void Zypper::assertZYppPtrGod()
     {
       // ask user whether to tell it to quit
       mbs_write_wrapped( Out::Info(out()) << "", _(
-	"PackageKit is blocking zypper. This happens if you have an"
-	" updater applet or other software management application using"
-	" PackageKit running."
+        "PackageKit is blocking zypper. This happens if you have an"
+        " updater applet or other software management application using"
+        " PackageKit running."
       ), 0, out().defaultFormatWidth( 100 ) );
 
       mbs_write_wrapped( Out::Info(out()) << "", _(
-	"We can ask PackageKit to interrupt the current action as soon as possible, but it depends on PackageKit how fast it will respond to this request."
+        "We can ask PackageKit to interrupt the current action as soon as possible, but it depends on PackageKit how fast it will respond to this request."
       ), 0, out().defaultFormatWidth( 100 ) );
 
       bool reply = read_bool_answer( PROMPT_PACKAGEKIT_QUIT, _("Ask PackageKit to quit?"), false );
@@ -102,15 +102,15 @@ void Zypper::assertZYppPtrGod()
       // tell it to quit
       while ( reply && still_locked )
       {
-	packagekit_suggest_quit();
-	::sleep( 2 );
-	if ( packagekit_running() )
-	{
-	  out().info(_("PackageKit is still running (probably busy)."));
-	  reply = read_bool_answer( PROMPT_PACKAGEKIT_QUIT, _("Try again?"), false );
-	}
-	else
-	  still_locked = false;
+        packagekit_suggest_quit();
+        ::sleep( 2 );
+        if ( packagekit_running() )
+        {
+          out().info(_("PackageKit is still running (probably busy)."));
+          reply = read_bool_answer( PROMPT_PACKAGEKIT_QUIT, _("Try again?"), false );
+        }
+        else
+          still_locked = false;
       }
     }
 
@@ -129,12 +129,12 @@ void Zypper::assertZYppPtrGod()
       { God = getZYpp(); }
       catch ( ZYppFactoryException & e )
       {
-	// this should happen only rarely, so no special handling here
-	ERR  << "still locked." << endl;
-	out().error( e.asString() );
+        // this should happen only rarely, so no special handling here
+        ERR  << "still locked." << endl;
+        out().error( e.asString() );
 
-	setExitCode( ZYPPER_EXIT_ZYPP_LOCKED );
-	ZYPP_THROW( ExitRequestException("ZYpp locked") );
+        setExitCode( ZYPPER_EXIT_ZYPP_LOCKED );
+        ZYPP_THROW( ExitRequestException("ZYpp locked") );
       }
     }
   }
@@ -162,11 +162,11 @@ namespace {
       PathInfo pi( dir_r );
       if ( pi.isExist() )
       {
-	if ( ! ( pi.isDir() && pi.userMayRWX() ) )
-	  mayuse = false;
+        if ( ! ( pi.isDir() && pi.userMayRWX() ) )
+          mayuse = false;
       }
       else
-	mayuse = userMayUseDir( dir_r.dirname() );
+        mayuse = userMayUseDir( dir_r.dirname() );
     }
     return mayuse;
   }
@@ -260,24 +260,17 @@ Out & Zypper::out()
   // PENDING SigINT? Some frequently called place to avoid exiting from within the signal handler?
   immediateExitCheck();
 
-  if ( _out_ptr )
-    return *_out_ptr;
-
-  cerr << "uninitialized output writer" << endl;
-  ZYPP_THROW( ExitRequestException("no output writer") );
-}
-
-Out *Zypper::outputWriter()
-{
-  return _out_ptr;
-}
-
-void Zypper::setOutputWriter(Out *out)
-{
-  if ( _out_ptr ) {
-    delete _out_ptr;
-    _out_ptr = nullptr;
+  if ( not _out_ptr ) {
+    _out_ptr = new OutNormal( Out::QUIET );
   }
+
+  return *_out_ptr;
+}
+
+void Zypper::setOutputWriter( Out *out )
+{
+  if ( _out_ptr && _out_ptr != out )  // prevent self destruct
+    delete _out_ptr;
   _out_ptr = out;
 }
 
@@ -300,16 +293,15 @@ int Zypper::processGlobalOptions()
   MIL << "START" << endl;
 
   //setup the default output, this could be overridden by cli values
-  OutNormal * p = new OutNormal( _config.verbosity );
-  p->setUseColors( _config.do_colors );
-  setOutputWriter( p );
+  out().setVerbosity( _config.verbosity );
+  out().setUseColors( _config.do_colors );
 
   std::vector<ZyppFlags::CommandGroup> globalOpts = _config.cliOptions();
   int nextFlag = searchPackagesHintHack::argvCmdIdx = ZyppFlags::parseCLI( _argc, _argv, globalOpts );
 
   out().info( str::Format(_("Verbosity: %d")) % _config.verbosity , Out::HIGH );
   DBG << "Verbosity " << _config.verbosity << endl;
-  DBG << "Output type " << _out_ptr->type() << endl;
+  DBG << "Output type " << out().type() << endl;
 
   // ======== other global options ========
   {
@@ -555,7 +547,10 @@ void Zypper::doCommand( int cmdArgc, char **cmdArgv, int firstFlag )
             repo.setName( url.asString() );
 
             repo.setMetadataPath( runtimeData().tmpdir / repo.alias() / "%AUTO%" );
-            repo.setPackagesPath( Pathname::assertprefix( _config.root_dir, ZYPPER_RPM_CACHE_DIR ) );
+
+            // Use @System dir name because libzypp will not automatically remove it and there is no user defined repository with that name
+            // Fixes bsc 1130873 - zypper package cache relocation broken
+            repo.setPackagesPath( Pathname::assertprefix( _config.root_dir, _config.rm_options.repoPackagesCachePath ) / "@System" );
 
             _rdata.temporary_repos.push_back( repo );
             DBG << "got additional repo: " << url << endl;
