@@ -3,6 +3,7 @@
 
 #include <string>
 #include <sstream>
+#include <optional>
 
 #include <zypp/base/Xml.h>
 #include <zypp/base/NonCopyable.h>
@@ -30,6 +31,9 @@ using namespace zypp;
 
 class Zypper;
 
+/// ProgressBars default end tags.
+enum class ProgressEnd { done, attention, error };
+
 ///////////////////////////////////////////////////////////////////
 namespace text
 {
@@ -240,24 +244,24 @@ namespace out
 
       if ( _layout._singleline )
       {
-	if ( _layout._gaped )
-	  _str << std::endl;
-	_str << _indent << element << std::endl;
+        if ( _layout._gaped )
+          _str << std::endl;
+        _str << _indent << element << std::endl;
       }
       else
       {
-	if ( _cpos != 0 && ! fitsOnLine( 1/*' '*/ + element.size() ) )
-	  endLine();
+        if ( _cpos != 0 && ! fitsOnLine( 1/*' '*/ + element.size() ) )
+          endLine();
 
-	if ( _cpos == 0 )
-	{
-	  if ( !_indent.empty() )
-	    printAndCount( _indent );
-	}
-	else
-	  printAndCount( " " );
+        if ( _cpos == 0 )
+        {
+          if ( !_indent.empty() )
+            printAndCount( _indent );
+        }
+        else
+          printAndCount( " " );
 
-	printAndCount( element );
+        printAndCount( element );
       }
     }
 
@@ -299,8 +303,8 @@ namespace out
     {
       if ( !_t.empty() )
       {
-	_t.setHeader( _formater.header() );
-	_str << _t;
+        _t.setHeader( _formater.header() );
+        _str << _t;
       }
     }
 
@@ -425,7 +429,7 @@ public:
   {
     QUIET  = 0,		///< Only important messages (no progress or status, only the result).
     NORMAL = 1,		///< Default output verbosity level. Progress for important tasks, moderate
-			///< amount of status messages, operation information, result.
+                        ///< amount of status messages, operation information, result.
     HIGH   = 2,		///< More detailed description of the operations.
     DEBUG  = 3		///< \todo drop this level in favor of zypper.log?
   } Verbosity;
@@ -522,18 +526,18 @@ private:
    * replacing optional \c %1% in \a title_r with size. */
   template <class TContainer, class TFormater>
   void container( const std::string & nodeName_r, const std::string & title_r,
-		  const TContainer & container_r, const TFormater & formater_r )
+                  const TContainer & container_r, const TFormater & formater_r )
   {
     TitleNode guard( XmlNode( *this, nodeName_r, XmlNode::Attr( "size", str::numstring( container_r.size() ) ) ),
-		     str::Format( title_r ) % container_r.size() );
+                     str::Format( title_r ) % container_r.size() );
     switch ( type() )
     {
       case TYPE_NORMAL:
-	writeContainer( std::cout, container_r, formater_r );
-	break;
+        writeContainer( std::cout, container_r, formater_r );
+        break;
       case TYPE_XML:
-	xmlWriteContainer( std::cout, container_r, formater_r );
-	break;
+        xmlWriteContainer( std::cout, container_r, formater_r );
+        break;
     }
   }
 
@@ -542,14 +546,14 @@ public:
    * replacing optional \c %1% in \a title_r with size. */
   template <class TContainer, class TFormater = out::ListFormater>
   void list( const std::string & nodeName_r, const std::string & title_r,
-	     const TContainer & container_r, const TFormater & formater_r = TFormater() )
+             const TContainer & container_r, const TFormater & formater_r = TFormater() )
   { container( nodeName_r, title_r, container_r, formater_r ); }
 
   /** Write table from container creating a TitleNode with \c size="nnn" attribute and
    * replacing optional \c %1% in \a title_r with size. */
   template <class TContainer, class TFormater = out::TableFormater>
   void table( const std::string & nodeName_r, const std::string & title_r,
-	      const TContainer & container_r, const TFormater & formater_r = TFormater() )
+              const TContainer & container_r, const TFormater & formater_r = TFormater() )
   { container( nodeName_r, title_r, container_r, formater_r ); }
 
 public:
@@ -734,9 +738,6 @@ public:
   /** Convenience class for progress output. */
   class ProgressBar;
 
-  /** Convenience class for download progress output. */
-  struct DownloadProgress;
-
   /**
    * Start of an operation with reported progress.
    *
@@ -770,12 +771,19 @@ public:
    * \param id      Identifier. Any string used to match multiple overlapping
    *                progress reports.
    * \param label   Progress description.
+   * \param donetag Optional string overwriting the default [done]/[error] tags.
    * \param error   <tt>false</tt> if the operation finished with success,
    *                <tt>true</tt> otherwise.
    */
   virtual void progressEnd(const std::string & id,
                            const std::string & label,
-                           bool error = false) = 0; // might be a string with error message instead
+                           const std::string & donetag,
+                           bool error = false) = 0;
+  /** \overload using the default [done]/[attention]/[error] tags in screen output. depending on \a donetag. */
+  void progressEnd( const std::string & id, const std::string & label, ProgressEnd donetag );
+  /** \overload using the default [done]/[error] tags in screen output depending on \a error. */
+  void progressEnd( const std::string & id, const std::string & label, bool error = false )
+  { progressEnd( id, label, error ? ProgressEnd::error : ProgressEnd::done ); }
   //@}
 
   /** \name Download progress with download rate */
@@ -872,6 +880,8 @@ public:
     return DtorReset( _verbosity, verbosity_r );
   }
 
+  /** Hint for a handler whether config would allow to use colors. */
+  virtual void setUseColors( bool yesno ) {}
 
 public:
   /** Return the type of the instance. */
@@ -977,7 +987,6 @@ public:
    */
   ProgressBar( Out & out_r, NoStartBar, const std::string & progressId_r, const std::string & label_r, unsigned current_r = 0, unsigned total_r = 0 )
     : _out( out_r )
-    , _error( indeterminate )
     , _progressId( progressId_r )
   {
     if ( total_r )
@@ -1014,9 +1023,9 @@ public:
   ~ProgressBar()
   {
     _progress.noSend();	// suppress ~ProgressData final report
-    if ( indeterminate( _error ) )
-      _error = ( _progress.reportValue() != 100 && _progress.reportPercent() );
-    _out.progressEnd( _progressId, outLabel( _progress.name() ), bool(_error) );
+    if ( not _donetag )
+      error( _progress.reportValue() != 100 && _progress.reportPercent() );
+    _out.progressEnd( _progressId, outLabel( _progress.name() ), *_donetag );
   }
 
   /** Immediately print the progress bar not waiting for a new trigger. */
@@ -1028,12 +1037,16 @@ public:
   { _progress.name( label_r ); print(); }
 
   /** Explicitly indicate the error condition for the final progress bar. */
-  void error( TriBool error_r = true )
-  { _error = error_r; }
+  void error( ProgressEnd donetag_r = ProgressEnd::error )
+  { _donetag = donetag_r; }
 
-  /** \overload to disambiguate. */
+  /** \overload just done/error.  */
   void error( bool error_r )
-  { _error = error_r; }
+  { _donetag = error_r ? ProgressEnd::error : ProgressEnd::done; }
+
+  /** Reset any error condition. */
+  void errorreset()
+  { _donetag.reset(); }
 
   /** \overload also change the progress bar label. */
   void error( const std::string & label_r )
@@ -1043,10 +1056,6 @@ public:
   void error( const char * label_r )
   { _progress.name( label_r ); error( true ); }
 
-  /** \overload also change the progress bar label. */
-  void error( TriBool error_r, const std::string & label_r )
-  { _progress.name( label_r ); error( error_r ); }
-
 public:
   /** \name Access the embedded ProgressData object */
   //@{
@@ -1087,83 +1096,13 @@ private:
 
 private:
   Out & _out;
-  TriBool _error;
+  std::optional<ProgressEnd> _donetag;
   ProgressData _progress;
   std::string _progressId;
   std::string _labelPrefix;
 };
 ///////////////////////////////////////////////////////////////////
 
-///////////////////////////////////////////////////////////////////
-/// \class Out::DownloadProgress
-/// \brief Listen on media::DownloadProgressReport to feed a ProgressBar.
-///
-/// Connect to media::DownloadProgressReport to feed a ProgressBar, but forward
-/// callbacks to any original receiver.
-///////////////////////////////////////////////////////////////////
-struct Out::DownloadProgress : public callback::ReceiveReport<media::DownloadProgressReport>
-{
-  DownloadProgress( Out::ProgressBar & progressbar_r )
-  : _progressbar( &progressbar_r )
-  , _oldReceiver( Distributor::instance().getReceiver() )
-  {
-    connect();
-  }
-
-  ~DownloadProgress()
-  {
-    if ( _oldReceiver )
-      Distributor::instance().setReceiver( *_oldReceiver );
-    else
-      Distributor::instance().noReceiver();
-  }
-
-  virtual void start( const Url & file, Pathname localfile )
-  {
-    (*_progressbar)->range( 100 );	// we'll receive %
-
-    if ( _oldReceiver )
-      _oldReceiver->start( file, localfile );
-  }
-
-  virtual bool progress( int value, const Url & file, double dbps_avg = -1, double dbps_current = -1 )
-  {
-    (*_progressbar)->set( value );
-
-    if ( _oldReceiver )
-      return _oldReceiver->progress( value, file, dbps_avg, dbps_current );
-    return true;
-  }
-
-  virtual Action problem( const Url & file, Error error, const std::string & description )
-  {
-    ERR << description << endl;
-
-    if ( _oldReceiver )
-      return _oldReceiver->problem( file, error, description );
-    return Receiver::problem( file, error, description );
-  }
-
-  virtual void finish( const Url & file, Error error, const std::string & reason )
-  {
-    if ( error == NO_ERROR )
-      (*_progressbar)->toMax();
-    else
-    {
-      ERR << reason << std::endl;
-      _progressbar->error();
-    }
-
-    if ( _oldReceiver )
-      _oldReceiver->finish( file, error, reason );
-  }
-
-private:
-  Out::ProgressBar * _progressbar;
-  Receiver * _oldReceiver;
-};
-///////////////////////////////////////////////////////////////////
-
 ///////////////////////////////////////////////////////////////////
 /// \class Out::Error
 /// \brief Convenience class Error reporting.
